==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebPaneDragStartEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebPaneDragStartEventArgsDetailDescription } from "./WebPaneDragStartEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPaneDragStartEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneDragStartEventArgsDetailDescriptionMetadata, _super);
    function WebPaneDragStartEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneDragStartEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPaneDragStartEventArgsDetailDescriptionMetadata.a == null) {
            WebPaneDragStartEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneDragStartEventArgsDetailDescriptionMetadata.c(WebPaneDragStartEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebPaneDragStartEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebPaneDragStartEventArgsDetailDescriptionMetadata.a);
        WebDockManagerPaneDescriptionMetadata.d(a);
        WebContentPaneDescriptionMetadata.d(a);
    };
    WebPaneDragStartEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneDragStartEventArgsDetail");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("SourcePane", "ExportedType:WebDockManagerPane");
        a.item("Panes", "Array:WebContentPaneDescription:ContentPane");
    };
    WebPaneDragStartEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPaneDragStartEventArgsDetailDescriptionMetadata.b(a);
        a.ad("WebPaneDragStartEventArgsDetail", function () { return new WebPaneDragStartEventArgsDetailDescription(); });
        a.ac("WebPaneDragStartEventArgsDetail", WebPaneDragStartEventArgsDetailDescriptionMetadata.a);
    };
    WebPaneDragStartEventArgsDetailDescriptionMetadata.$t = markType(WebPaneDragStartEventArgsDetailDescriptionMetadata, 'WebPaneDragStartEventArgsDetailDescriptionMetadata');
    WebPaneDragStartEventArgsDetailDescriptionMetadata.a = null;
    return WebPaneDragStartEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPaneDragStartEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebPaneDragStartEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebPaneDragStartEventArgsDetailDescription } from "./WebPaneDragStartEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPaneDragStartEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneDragStartEventArgsDetailDescriptionMetadata, _super);
    function WebPaneDragStartEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneDragStartEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPaneDragStartEventArgsDetailDescriptionMetadata.a == null) {
            WebPaneDragStartEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneDragStartEventArgsDetailDescriptionMetadata.c(WebPaneDragStartEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebPaneDragStartEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebPaneDragStartEventArgsDetailDescriptionMetadata.a);
        WebDockManagerPaneDescriptionMetadata.d(a);
    };
    WebPaneDragStartEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneDragStartEventArgsDetail");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("SourcePane", "ExportedType:WebDockManagerPane");
        a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
    };
    WebPaneDragStartEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPaneDragStartEventArgsDetailDescriptionMetadata.b(a);
        a.ae("WebPaneDragStartEventArgsDetail", function () { return new WebPaneDragStartEventArgsDetailDescription(); });
        a.ad("WebPaneDragStartEventArgsDetail", WebPaneDragStartEventArgsDetailDescriptionMetadata.a);
    };
    WebPaneDragStartEventArgsDetailDescriptionMetadata.$t = markType(WebPaneDragStartEventArgsDetailDescriptionMetadata, 'WebPaneDragStartEventArgsDetailDescriptionMetadata');
    WebPaneDragStartEventArgsDetailDescriptionMetadata.a = null;
    return WebPaneDragStartEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPaneDragStartEventArgsDetailDescriptionMetadata };
